==> basic-core-4.0.0-20250902.030401-71-sources.jar: com/tydic/dyc/pro/base/core/dictionary/enums/DmcCommCheckItemVarificationIndexEnum.java <==
package com.tydic.dyc.pro.base.core.dictionary.enums;

public enum DmcCommCheckItemVarificationIndexEnum implements DictionaryEnum{
    DIS_RATE("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "1", "商品折扣率", "校验指标项"),
    SUPPLIER_PRICE_SINGLE_CHNG_RATE("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "2", "供货价单次浮动率", "校验指标项"),
    SUPPLIER_PRICE_THREE_CHNG_RATE("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "3", "供货价3月内上浮率", "校验指标项"),
    SUPPLIER_PRICE_WEEK_CHNG_NUM("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "4", "供货价1周内仅允许变更2次", "校验指标项"),
    XUN_PRICE("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "5", "固定价", "校验指标项"),
    EC_PRICE("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "6", "社会电商参考价", "校验指标项"),
    YOUKE_PRICE("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "7", "游客价95%折扣", "校验指标项"),
    JD_PRICE("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "8", "京东自营官网价*京东折扣率", "校验指标项"),
    REFER_PRICE("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "9", "价格指数", "校验指标项"),

    image_porn("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "image_porn", "图片涉黄", "校验指标项"),
    image_terrorism("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "image_terrorism", "图片涉敏感内容或风险人物", "校验指标项"),
    image_ad("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "image_ad", "图片涉广告", "校验指标项"),
    image_live("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "image_live", "图片涉不良场景", "校验指标项"),

    text_spam("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "text_spam", "文字涉垃圾信息", "校验指标项"),
    text_politics("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "text_politics", "文字涉敏感词", "校验指标项"),
    text_abuse("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "text_abuse", "文字涉辱骂", "校验指标项"),
    text_terrorism("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "text_terrorism", "文字涉暴恐", "校验指标项"),
    text_porn("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "text_porn", "文字涉黄", "校验指标项"),
    text_contraband("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "text_contraband", "文字涉违禁信息", "校验指标项"),
    text_ad("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "text_ad", "文字涉广告", "校验指标项");

    /**
     * 编码
     */
    private String dictionaryCode;
    /**
     * 编码
     */
    private String code;
    /**
     * 编码值
     */
    private String value;
    /**
     * 名称
     */
    private String dictionaryName;
    DmcCommCheckItemVarificationIndexEnum(String dictionaryCode, String code, String value, String dictionaryName) {
        this.dictionaryCode = dictionaryCode;
        this.code = code;
        this.value = value;
        this.dictionaryName = dictionaryName;
    }
    @Override
    public String getDictionaryCode() {
        return dictionaryCode;
    }

    @Override
    public String getDictionaryName() {
        return dictionaryName;
    }

    @Override
    public String getCode() {
        return code;
    }

    @Override
    public String getValue() {
        return value;
    }
}

==> basic-core-4.0.0-20250922.044938-87-sources.jar: com/tydic/dyc/pro/base/core/dictionary/enums/DmcCommCheckItemVarificationIndexEnum.java <==
package com.tydic.dyc.pro.base.core.dictionary.enums;

public enum DmcCommCheckItemVarificationIndexEnum implements DictionaryEnum{
    DIS_RATE("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "1", "商品折扣率", "校验指标项"),
    SUPPLIER_PRICE_SINGLE_CHNG_RATE("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "2", "供货价单次浮动率", "校验指标项"),
    SUPPLIER_PRICE_THREE_CHNG_RATE("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "3", "供货价3月内上浮率", "校验指标项"),
    SUPPLIER_PRICE_WEEK_CHNG_NUM("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "4", "供货价1周内仅允许变更2次", "校验指标项"),
    XUN_PRICE("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "5", "固定价", "校验指标项"),
    EC_PRICE("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "6", "社会电商参考价", "校验指标项"),
    YOUKE_PRICE("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "7", "自有商城实际销售价*商城销售价折扣率", "校验指标项"),
    JD_PRICE("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "8", "京东自营官网价*京东折扣率", "校验指标项"),
    REFER_PRICE("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "9", "价格指数", "校验指标项"),

    image_porn("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "image_porn", "图片涉黄", "校验指标项"),
    image_terrorism("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "image_terrorism", "图片涉敏感内容或风险人物", "校验指标项"),
    image_ad("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "image_ad", "图片涉广告", "校验指标项"),
    image_live("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "image_live", "图片涉不良场景", "校验指标项"),

    text_spam("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "text_spam", "文字涉垃圾信息", "校验指标项"),
    text_politics("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "text_politics", "文字涉敏感词", "校验指标项"),
    text_abuse("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "text_abuse", "文字涉辱骂", "校验指标项"),
    text_terrorism("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "text_terrorism", "文字涉暴恐", "校验指标项"),
    text_porn("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "text_porn", "文字涉黄", "校验指标项"),
    text_contraband("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "text_contraband", "文字涉违禁信息", "校验指标项"),
    text_ad("DMC_COMM_CHECK_ITEM_VARIFICATION_INDEX", "text_ad", "文字涉广告", "校验指标项");

    /**
     * 编码
     */
    private String dictionaryCode;
    /**
     * 编码
     */
    private String code;
    /**
     * 编码值
     */
    private String value;
    /**
     * 名称
     */
    private String dictionaryName;
    DmcCommCheckItemVarificationIndexEnum(String dictionaryCode, String code, String value, String dictionaryName) {
        this.dictionaryCode = dictionaryCode;
        this.code = code;
        this.value = value;
        this.dictionaryName = dictionaryName;
    }
    @Override
    public String getDictionaryCode() {
        return dictionaryCode;
    }

    @Override
    public String getDictionaryName() {
        return dictionaryName;
    }

    @Override
    public String getCode() {
        return code;
    }

    @Override
    public String getValue() {
        return value;
    }
}
